@@ -12,12 +12,14 @@ package Jedi::Request;
 
 use Moo;
 
-our $VERSION = '0.01';    # VERSION
+our $VERSION = '0.02';    # VERSION
 
 use HTTP::Body;
 use CGI::Deurl::XS 'parse_query_string';
 use CGI::Cookie::XS;
 
+has 'jedi_env' => ( is => 'ro', default => sub {'development'} );
+
 has 'env' => ( is => 'ro', required => 1 );
 
 has 'path' => ( is => 'ro', required => 1 );
@@ -86,7 +88,7 @@ Jedi::Request - Jedi Request
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -96,6 +98,10 @@ You can get data from it, to generate your response
 
 =head1 ATTRIBUTES
 
+=head2 jedi_env
+
+The environment of jedi apps
+
 =head2 env
 
 The environment variable, as it received from PSGI
